#
# spec file for package python-pydicom
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15allpythons}
Name:           python-pydicom
Version:        2.3.1
Release:        bp156.1.3
Summary:        Pure python package for DICOM medical file reading and writing
License:        MIT
URL:            https://github.com/darcymason/pydicom
Source:         https://files.pythonhosted.org/packages/source/p/pydicom/pydicom-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pydicom-data}
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  python3-gdcm
# /SECTION
BuildArch:      noarch
Requires(post): update-alternatives
Requires(postun):update-alternatives
%python_subpackages

%description
pydicom is a pure python package for parsing DICOM files
into natural pythonic structures for further manipulation.
Modified datasets can be written again to DICOM format files.

DICOM is a standard (http://medical.nema.org) for communicating
medical images and related information such as reports
and radiotherapy objects.

%prep
%setup -q -n pydicom-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/pydicom
%python_expand rm -r %{buildroot}%{$python_sitelib}/pydicom/{benchmarks,tests,data/test_files}
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8

skips="test_fetch_data_files"
# see https://github.com/pydicom/pydicom-data/issues/9
skips="$skips or OBXXXX1A or (test_can_access_unsupported_dataset and (TestPillowHandler_JPEG or TestPillowHandler_JPEG2K))"

# Failures only on ppc64
skips="$skips or test_invalid_arr_dtype_raises or TestHandlerGenerateMultiplex or TestHandlerMultiplexArray"
# Failures only on i586
skips="$skips or test_write_file_id or test_file_id or test_encapsulate_bot_large_raises or (TestPillowHandler_JPEG2K and test_array)"

# see https://github.com/pydicom/pydicom/issues/1697
ignores="--ignore pydicom/tests/test_dataset.py --ignore pydicom/tests/test_data_manager.py"

%pytest -rs pydicom/tests $ignores -k "not ($skips)"

%post
%python_install_alternative pydicom

%postun
%python_uninstall_alternative pydicom

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/pydicom
%{python_sitelib}/pydicom
%{python_sitelib}/pydicom-%{version}.dist-info

%changelog
* Tue Jan 16 2024 Axel Braun <axel.braun@gmx.de>
- switch to wheel and enable %%{?sle15allpythons}
* Sat Dec  3 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2.3.1:
  * Small fix to make 2.3.X compatible with Python 3.11.
* Mon Oct 10 2022 John Vandenberg <jayvdb@gmail.com>
- Add BD pydicom-data test data, and unskip many tests that now pass
* Sat Sep 24 2022 John Vandenberg <jayvdb@gmail.com>
- Skip a lot of tests, mostly due to missing test data, but there
  are over 1900 still passing.
- Update to v2.3.0
  * See https://github.com/pydicom/pydicom/tree/master/doc/release_notes
* Fri Dec 10 2021 pgajdos@suse.com
- do not require pytest-runner for build
* Tue Mar 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.4.2:
  * no upstream changelog
* Tue Jul 23 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.3.0:
  * no upstream changelog
* Fri Mar  8 2019 John Vandenberg <jayvdb@gmail.com>
- Reinstate test unit test_code_file which appears to be stable now
- Use PyPI sdist as source
* Wed Jan  2 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.2.2:
  * more python 3.7 fixes
* Thu Nov  1 2018 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.2.0:
  * No obvious upstream changelog
- Drop python37.patch should be fixed upstream
* Thu Aug 30 2018 Tomáš Chvátal <tchvatal@suse.com>
- Disable test_code_file as it randomly fails in OBS
* Wed Aug 29 2018 tchvatal@suse.com
- Update to 1.1.0:
  * License is distributed
  * Various speed improvements
- Add patch to work with python 3.7:
  * python37.patch
* Mon Sep 11 2017 jengelh@inai.de
- Make package description neutral and compact it.
* Mon Sep 11 2017 toddrme2178@gmail.com
- Implement single-spec version
* Thu Oct 13 2016 toddrme2178@gmail.com
- Update to version 0.9.9
  + Major changes / enhancements
  * All dicom dictionaries updated (standard dictionary, UID
    dictionary, and private dictionaries)
  * Dicom commands also added to dictionary
  * Ability to work with DICOMDIR:  read_dicomdir() function and
    DicomDir class. Example file show_dicomdir.py file added to
    examples subdirectory.
  * codify.py: Produce python/pydicom source code from a dicom
    file.
  * a number of python 3 compatibility enhancements
  * setup.py uses ez_setup only if setuptools not already
    installed
  * exceptions carry tag info with them, to aid in debugging
  + Contrib file changes
  * pydicom_series:  force parameter added (Nil Goyette)
  * dcm_qt_tree: switch to OrderedDict to preserve ordering of
    tags (Padraig Looney)
- Rename package to python-dicom to python-pydicom to conform to python
  package naming policies.
- spec file completely rewritten.
- Remove unneeded python-dicom-remove-obsolete-distribute-support.patch
* Tue Dec 17 2013 p.drouand@gmail.com
- Update to version 0.9.8
  + No changelog available
- Add python-dicom-remove-obsolete-distribute-support.patch; setup
  script try to import setuptools from distribute
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Fri Aug 17 2012 scorot@free.fr
- fix build for SLE 11 x86_64
* Tue Aug  7 2012 toddrme2178@gmail.com
- Initial version
